@@ -1,4 +1,5 @@
 import decimal
+import json
 from datetime import datetime
 
 from boto3.dynamodb.conditions import Attr, Key
@@ -13,16 +14,31 @@ LOGS_METRICS_FETCHING_TABLE = 'logs.cloud_metric_fetching'
 LOGS_API_REQUEST_TABLE = 'logs.api_request'
 COMPONENTS_TABLE = 'component.info'
 ATOMIC_COUNTER_TABLE = 'atomic.counter'
+ANOMALIES_TABLE = 'anomalies.items'
+
+DEV_ANOMALIES_TABLE = 'dev.anomalies.items'
+
+
+def prepare_decimal(item):
+  return json.loads(json.dumps(item), parse_float=decimal.Decimal)
 
 
 # ########### ATOMIC COUNTER ###################
-def increment_atomic_counter(counter_type, dynamodb):
+def increment_atomic_counter(counter_type, n_values, dynamodb):
+  '''
+  Increments atomic counter for the specified counter type
+  Returns the updated atomic counter as an int
+  '''
   key_dict = {"name": counter_type}
   update_expression = "set val = val + :v"
-  expression_attribute_values = {':v': decimal.Decimal(1)}
+  expression_attribute_values = {':v': decimal.Decimal(n_values)}
   table_name = ATOMIC_COUNTER_TABLE
-  values = update_item(key_dict, update_expression, expression_attribute_values, table_name, dynamodb)
-  return values
+  response = update_item(key_dict, update_expression, expression_attribute_values, table_name, dynamodb)
+  if response['ResponseMetadata']['HTTPStatusCode'] == 200:
+    return int(response['Attributes']['val'])
+  else:
+    raise Exception('Error with {} status code, in update of {} atomic counter.'.format(
+      str(response['ResponseMetadata']['HTTPStatusCode']), counter_type))
 
 
 # ########### ALERTS ###########################
@@ -260,10 +276,10 @@ def query_most_recent_metric_fetching_log(component_id, dynamodb):
     return None
 
 
-def insert_api_requests_log(api_name, request_timestamp, response_status_code, request, response, dynamodb):
+def insert_api_request_log(api_name, request_timestamp, response_status_code, request, response, dynamodb):
   """
-  insert_api_requests_log(api_name='anomalarm_metrics', request_timestamp=1603466177, response_status_code='202',
-                          request={'key': 'value'}, response={'key': 'value'}, dynamodb)
+  insert_api_request_log(api_name='anomalarm_metrics', request_timestamp=1603466177, response_status_code='202',
+                         request={'key': 'value'}, response={'key': 'value'}, dynamodb)
   """
   item = {
     'api_name': api_name,
@@ -276,6 +292,71 @@ def insert_api_requests_log(api_name, request_timestamp, response_status_code, r
   return response
 
 
+# ############# ANOMALIES ####################
+def insert_new_anomaly(id, timestamp, metric_id, value, dynamodb, is_dev_env=False):
+  """
+  insert_new_anomaly(id="125123", timestamp=1599563224, metric_id="m412", value=123.44, dynamodb=dynamodb)
+  """
+  item = prepare_decimal({'id': id, 'timestamp': timestamp, 'metric_id': metric_id, 'value': value})
+  table_name = ANOMALIES_TABLE if not is_dev_env else DEV_ANOMALIES_TABLE
+  return put_item(item, table_name, dynamodb)
+
+
+def update_anomaly_relations(id,
+                             timestamp,
+                             cross_correlations,
+                             possible_related_anomalies,
+                             possible_related_matches,
+                             dynamodb,
+                             is_dev_env=False):
+  """
+  update_anomaly_relations(id="125123",
+                           timestamp=1599563224,
+                           cross_correlations={
+                             "web-server-1.cpu0.iowait": {
+                               "coefficient": 0.95752,
+                               "shifted": 0,
+                               "shifted_coefficient": 0.95752
+                             },
+                           },
+                           possible_related_anomalies={
+                             "256826": {
+                               "metric_id": "web-server-1.mysql.counters.handlerRead_key",
+                               "timestamp": 1599563164
+                             },
+                           },
+                           possible_related_matches={
+                             "169560": {
+                               "timestamp": 1599563230,
+                               "fp id": 8821,
+                               "layer id": "None",
+                               "metric_id": "web-server-2.mariadb.localhost:3306.mysql.bytes_sent"
+                             }
+                           },
+                           dynamodb=dynamodb)
+  """
+  key_dict = prepare_decimal({'id': id, 'timestamp': timestamp})
+  update_expression = 'set cross_correlations=:cc, possible_related_anomalies=:pra, possible_related_matches=:prm'
+  expression_attribute_values = prepare_decimal({
+    ':cc': cross_correlations,
+    ':pra': possible_related_anomalies,
+    ':prm': possible_related_matches
+  })
+  table_name = ANOMALIES_TABLE if not is_dev_env else DEV_ANOMALIES_TABLE
+  return update_item(key_dict, update_expression, expression_attribute_values, table_name, dynamodb)
+
+
+def terminate_anomaly(id, timestamp, end_timestamp, dynamodb, is_dev_env=False):
+  """
+  terminate_anomaly(id="125123", timestamp=1599563224, end_timestamp=1599663224, dynamodb=dynamodb)
+  """
+  key_dict = prepare_decimal({'id': id, 'timestamp': timestamp})
+  update_expression = 'set end_timestamp=:ts'
+  expression_attribute_values = prepare_decimal({':ts': end_timestamp})
+  table_name = ANOMALIES_TABLE if not is_dev_env else DEV_ANOMALIES_TABLE
+  return update_item(key_dict, update_expression, expression_attribute_values, table_name, dynamodb)
+
+
 # ############# EXAMPLES #####################
 def update_values_in_dict_attr():
   """
