@@ -41,9 +41,15 @@ class MetricModel(object):
   def get_dimension_name(self):
     return self.dimension_name
 
+  def get_component_id(self):
+    return self.component_id
+
   def update_is_active(self, is_active_value):
     self.is_active = is_active_value
 
+  def update_component_id(self, component_id):
+    self.component_id = component_id
+
   def to_dict(self):
     """
     Returns a dict representation of a MetricModel instance for serialization.
